@@ -1,14 +1,27 @@
-package Dist::Zilla::Plugin::DualBuilders;
+#
+# This file is part of Dist-Zilla-Plugin-DualBuilders
+#
+# This software is copyright (c) 2010 by Apocalypse.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
 use strict; use warnings;
-our $VERSION = '0.03';
+package Dist::Zilla::Plugin::DualBuilders;
+BEGIN {
+  $Dist::Zilla::Plugin::DualBuilders::VERSION = '1.000';
+}
+BEGIN {
+  $Dist::Zilla::Plugin::DualBuilders::AUTHORITY = 'cpan:APOCAL';
+}
 
-use Moose 1.01;
+# ABSTRACT: Allows use of Module::Build and ExtUtils::MakeMaker in a dzil dist
+
+use Moose 1.03;
+
+with 'Dist::Zilla::Role::PrereqSource' => { -version => '3.101461' };
+with 'Dist::Zilla::Role::InstallTool' => { -version => '3.101461' };
 
-# TODO wait for improved Moose that allows "with 'Foo::Bar' => { -version => 1.23 };"
-use Dist::Zilla::Role::PrereqSource 3.101461;
-use Dist::Zilla::Role::InstallTool 3.101461;
-with 'Dist::Zilla::Role::PrereqSource';
-with 'Dist::Zilla::Role::InstallTool';
 
 {
 	use Moose::Util::TypeConstraints 1.01;
@@ -77,7 +90,7 @@ sub register_prereqs {
 
 			# As of DZIL v2.101170 DZ:P:Makemaker adds to configure only
 			$config_prereq->clear_requirement( 'ExtUtils::MakeMaker' );
-			$self->log_debug( 'Preferring "build", removing ExtUtils::MakeMaker from prereqs' );
+			$self->log_debug( 'Preferring Module::Build, removing ExtUtils::MakeMaker from prereqs' );
 		} elsif ( $self->prefer eq 'make' ) {
 			# Get rid of MB stuff
 			$self->_buildver( $config_hash->{'Module::Build'} );
@@ -85,7 +98,7 @@ sub register_prereqs {
 			# As of DZIL v2.101170 DZ:P:ModuleBuild adds to configure and build
 			$config_prereq->clear_requirement( 'Module::Build' );
 			$build_prereq->clear_requirement( 'Module::Build' );
-			$self->log_debug( 'Preferring "make", removing Module::Build from prereqs' );
+			$self->log_debug( 'Preferring ExtUtils::MakeMaker, removing Module::Build from prereqs' );
 		}
 	} elsif ( exists $config_hash->{'Module::Build'} and $self->prefer eq 'make' ) {
 		$self->log_fatal( 'Detected Module::Build in the config but you preferred ExtUtils::MakeMaker!' );
@@ -102,14 +115,22 @@ no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
+
+__END__
 =pod
 
-=for stopwords AnnoCPAN CPAN CPANTS Kwalitee MakeMaker ModuleBuild RT dist dzil prereq prereqs
+=for Pod::Coverage register_prereqs setup_installer
+
+=for stopwords MakeMaker ModuleBuild dist dzil prereq prereqs
 
 =head1 NAME
 
 Dist::Zilla::Plugin::DualBuilders - Allows use of Module::Build and ExtUtils::MakeMaker in a dzil dist
 
+=head1 VERSION
+
+  This document describes v1.000 of Dist::Zilla::Plugin::DualBuilders - released December 13, 2010 as part of Dist-Zilla-Plugin-DualBuilders.
+
 =head1 DESCRIPTION
 
 This plugin allows you to specify ModuleBuild and MakeMaker in your L<Dist::Zilla> F<dist.ini> and select
@@ -121,87 +142,148 @@ and this is obviously not what you want!
 	[MakeMaker] ; or [MakeMaker::Awesome], will work too :)
 	[DualBuilders] ; needs to be specified *AFTER* the builders
 
-This plugin accepts the following options:
+=head1 ATTRIBUTES
 
-=over 4
-
-=item * prefer
+=head2 prefer
 
 Sets your preferred builder. This builder will be the one added to the prereqs. Valid options are: "make" or "build".
 
 The default is: build
 
-=back
-
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
 L<Dist::Zilla>
 
+=back
+
+=for :stopwords CPAN AnnoCPAN RT CPANTS Kwalitee diff IRC
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-	perldoc Dist::Zilla::Plugin::DualBuilders
+  perldoc Dist::Zilla::Plugin::DualBuilders
 
 =head2 Websites
 
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
 =over 4
 
-=item * Search CPAN
+=item *
+
+Search CPAN
 
 L<http://search.cpan.org/dist/Dist-Zilla-Plugin-DualBuilders>
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item *
 
-L<http://annocpan.org/dist/Dist-Zilla-Plugin-DualBuilders>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-DualBuilders>
-
-=item * CPAN Forum
-
-L<http://cpanforum.com/dist/Dist-Zilla-Plugin-DualBuilders>
-
-=item * RT: CPAN's Request Tracker
+RT: CPAN's Bug Tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-DualBuilders>
 
-=item * CPANTS Kwalitee
+=item *
+
+AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Dist-Zilla-Plugin-DualBuilders>
+
+=item *
+
+CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-DualBuilders>
+
+=item *
+
+CPAN Forum
+
+L<http://cpanforum.com/dist/Dist-Zilla-Plugin-DualBuilders>
+
+=item *
+
+CPANTS Kwalitee
 
 L<http://cpants.perl.org/dist/overview/Dist-Zilla-Plugin-DualBuilders>
 
-=item * CPAN Testers Results
+=item *
+
+CPAN Testers Results
 
 L<http://cpantesters.org/distro/D/Dist-Zilla-Plugin-DualBuilders.html>
 
-=item * CPAN Testers Matrix
+=item *
+
+CPAN Testers Matrix
 
 L<http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-DualBuilders>
 
-=item * Git Source Code Repository
+=back
 
-L<http://github.com/apocalypse/perl-dist-zilla-plugin-dualbuilders>
+=head2 Internet Relay Chat
+
+You can get live help by using IRC ( Internet Relay Chat ). If you don't know what IRC is,
+please read this excellent guide: L<http://en.wikipedia.org/wiki/Internet_Relay_Chat>. Please
+be courteous and patient when talking to us, as we might be busy or sleeping! You can join
+those networks/channels and get help:
+
+=over 4
+
+=item *
+
+irc.perl.org
+
+You can connect to the server at 'irc.perl.org' and join this channel: #perl-help then talk to this person for help: Apocalypse.
+
+=item *
+
+irc.freenode.net
+
+You can connect to the server at 'irc.freenode.net' and join this channel: #perl then talk to this person for help: Apocal.
+
+=item *
+
+irc.efnet.org
+
+You can connect to the server at 'irc.efnet.org' and join this channel: #perl then talk to this person for help: Ap0cal.
 
 =back
 
-=head2 Bugs
+=head2 Bugs / Feature Requests
 
-Please report any bugs or feature requests to C<bug-dist-zilla-plugin-dualbuilders at rt.cpan.org>, or through
+Please report any bugs or feature requests by email to C<bug-dist-zilla-plugin-dualbuilders at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Zilla-Plugin-DualBuilders>.  I will be
 notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<http://github.com/apocalypse/perl-dist-zilla-plugin-dualbuilders>
+
+  git clone git://github.com/apocalypse/perl-dist-zilla-plugin-dualbuilders.git
+
 =head1 AUTHOR
 
-Apocalypse E<lt>apocal@cpan.orgE<gt>
+Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 by Apocalypse
+This software is copyright (c) 2010 by Apocalypse.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the LICENSE file included with this module.
+The full text of the license can be found in the LICENSE file included with this distribution.
 
 =cut
+
